@@ -38,6 +38,27 @@ class CfnMicrosoftAD(
 
     :cloudformationResource: AWS::DirectoryService::MicrosoftAD
     :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html
+
+    Example::
+
+        # The code below shows an example of how to instantiate this type.
+        # The values are placeholders you should change.
+        import aws_cdk.aws_directoryservice as directoryservice
+        
+        cfn_microsoft_aD = directoryservice.CfnMicrosoftAD(self, "MyCfnMicrosoftAD",
+            name="name",
+            password="password",
+            vpc_settings=directoryservice.CfnMicrosoftAD.VpcSettingsProperty(
+                subnet_ids=["subnetIds"],
+                vpc_id="vpcId"
+            ),
+        
+            # the properties below are optional
+            create_alias=False,
+            edition="edition",
+            enable_sso=False,
+            short_name="shortName"
+        )
     '''
 
     def __init__(
@@ -45,34 +66,34 @@ class CfnMicrosoftAD(
         scope: aws_cdk.core.Construct,
         id: builtins.str,
         *,
-        name: builtins.str,
-        password: builtins.str,
-        vpc_settings: typing.Union["CfnMicrosoftAD.VpcSettingsProperty", aws_cdk.core.IResolvable],
         create_alias: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
         edition: typing.Optional[builtins.str] = None,
         enable_sso: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
+        name: builtins.str,
+        password: builtins.str,
         short_name: typing.Optional[builtins.str] = None,
+        vpc_settings: typing.Union["CfnMicrosoftAD.VpcSettingsProperty", aws_cdk.core.IResolvable],
     ) -> None:
         '''Create a new ``AWS::DirectoryService::MicrosoftAD``.
 
         :param scope: - scope in which this resource is defined.
         :param id: - scoped id of the resource.
-        :param name: ``AWS::DirectoryService::MicrosoftAD.Name``.
-        :param password: ``AWS::DirectoryService::MicrosoftAD.Password``.
-        :param vpc_settings: ``AWS::DirectoryService::MicrosoftAD.VpcSettings``.
         :param create_alias: ``AWS::DirectoryService::MicrosoftAD.CreateAlias``.
         :param edition: ``AWS::DirectoryService::MicrosoftAD.Edition``.
         :param enable_sso: ``AWS::DirectoryService::MicrosoftAD.EnableSso``.
+        :param name: ``AWS::DirectoryService::MicrosoftAD.Name``.
+        :param password: ``AWS::DirectoryService::MicrosoftAD.Password``.
         :param short_name: ``AWS::DirectoryService::MicrosoftAD.ShortName``.
+        :param vpc_settings: ``AWS::DirectoryService::MicrosoftAD.VpcSettings``.
         '''
         props = CfnMicrosoftADProps(
-            name=name,
-            password=password,
-            vpc_settings=vpc_settings,
             create_alias=create_alias,
             edition=edition,
             enable_sso=enable_sso,
+            name=name,
+            password=password,
             short_name=short_name,
+            vpc_settings=vpc_settings,
         )
 
         jsii.create(self.__class__, self, [scope, id, props])
@@ -95,12 +116,6 @@ class CfnMicrosoftAD(
         '''
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
-    @jsii.python.classproperty # type: ignore[misc]
-    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
-        '''The CloudFormation resource type name for this resource class.'''
-        return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))
-
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="attrAlias")
     def attr_alias(self) -> builtins.str:
@@ -117,55 +132,17 @@ class CfnMicrosoftAD(
         '''
         return typing.cast(typing.List[builtins.str], jsii.get(self, "attrDnsIpAddresses"))
 
+    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
+        '''The CloudFormation resource type name for this resource class.'''
+        return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))
+
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="cfnProperties")
     def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))
 
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="name")
-    def name(self) -> builtins.str:
-        '''``AWS::DirectoryService::MicrosoftAD.Name``.
-
-        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-name
-        '''
-        return typing.cast(builtins.str, jsii.get(self, "name"))
-
-    @name.setter
-    def name(self, value: builtins.str) -> None:
-        jsii.set(self, "name", value)
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="password")
-    def password(self) -> builtins.str:
-        '''``AWS::DirectoryService::MicrosoftAD.Password``.
-
-        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-password
-        '''
-        return typing.cast(builtins.str, jsii.get(self, "password"))
-
-    @password.setter
-    def password(self, value: builtins.str) -> None:
-        jsii.set(self, "password", value)
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="vpcSettings")
-    def vpc_settings(
-        self,
-    ) -> typing.Union["CfnMicrosoftAD.VpcSettingsProperty", aws_cdk.core.IResolvable]:
-        '''``AWS::DirectoryService::MicrosoftAD.VpcSettings``.
-
-        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-vpcsettings
-        '''
-        return typing.cast(typing.Union["CfnMicrosoftAD.VpcSettingsProperty", aws_cdk.core.IResolvable], jsii.get(self, "vpcSettings"))
-
-    @vpc_settings.setter
-    def vpc_settings(
-        self,
-        value: typing.Union["CfnMicrosoftAD.VpcSettingsProperty", aws_cdk.core.IResolvable],
-    ) -> None:
-        jsii.set(self, "vpcSettings", value)
-
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="createAlias")
     def create_alias(
@@ -215,6 +192,32 @@ class CfnMicrosoftAD(
     ) -> None:
         jsii.set(self, "enableSso", value)
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="name")
+    def name(self) -> builtins.str:
+        '''``AWS::DirectoryService::MicrosoftAD.Name``.
+
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-name
+        '''
+        return typing.cast(builtins.str, jsii.get(self, "name"))
+
+    @name.setter
+    def name(self, value: builtins.str) -> None:
+        jsii.set(self, "name", value)
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="password")
+    def password(self) -> builtins.str:
+        '''``AWS::DirectoryService::MicrosoftAD.Password``.
+
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-password
+        '''
+        return typing.cast(builtins.str, jsii.get(self, "password"))
+
+    @password.setter
+    def password(self, value: builtins.str) -> None:
+        jsii.set(self, "password", value)
+
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="shortName")
     def short_name(self) -> typing.Optional[builtins.str]:
@@ -228,6 +231,24 @@ class CfnMicrosoftAD(
     def short_name(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "shortName", value)
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="vpcSettings")
+    def vpc_settings(
+        self,
+    ) -> typing.Union["CfnMicrosoftAD.VpcSettingsProperty", aws_cdk.core.IResolvable]:
+        '''``AWS::DirectoryService::MicrosoftAD.VpcSettings``.
+
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-vpcsettings
+        '''
+        return typing.cast(typing.Union["CfnMicrosoftAD.VpcSettingsProperty", aws_cdk.core.IResolvable], jsii.get(self, "vpcSettings"))
+
+    @vpc_settings.setter
+    def vpc_settings(
+        self,
+        value: typing.Union["CfnMicrosoftAD.VpcSettingsProperty", aws_cdk.core.IResolvable],
+    ) -> None:
+        jsii.set(self, "vpcSettings", value)
+
     @jsii.data_type(
         jsii_type="@aws-cdk/aws-directoryservice.CfnMicrosoftAD.VpcSettingsProperty",
         jsii_struct_bases=[],
@@ -245,6 +266,17 @@ class CfnMicrosoftAD(
             :param vpc_id: ``CfnMicrosoftAD.VpcSettingsProperty.VpcId``.
 
             :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-directoryservice-microsoftad-vpcsettings.html
+
+            Example::
+
+                # The code below shows an example of how to instantiate this type.
+                # The values are placeholders you should change.
+                import aws_cdk.aws_directoryservice as directoryservice
+                
+                vpc_settings_property = directoryservice.CfnMicrosoftAD.VpcSettingsProperty(
+                    subnet_ids=["subnetIds"],
+                    vpc_id="vpcId"
+                )
             '''
             self._values: typing.Dict[str, typing.Any] = {
                 "subnet_ids": subnet_ids,
@@ -287,38 +319,59 @@ class CfnMicrosoftAD(
     jsii_type="@aws-cdk/aws-directoryservice.CfnMicrosoftADProps",
     jsii_struct_bases=[],
     name_mapping={
-        "name": "name",
-        "password": "password",
-        "vpc_settings": "vpcSettings",
         "create_alias": "createAlias",
         "edition": "edition",
         "enable_sso": "enableSso",
+        "name": "name",
+        "password": "password",
         "short_name": "shortName",
+        "vpc_settings": "vpcSettings",
     },
 )
 class CfnMicrosoftADProps:
     def __init__(
         self,
         *,
-        name: builtins.str,
-        password: builtins.str,
-        vpc_settings: typing.Union[CfnMicrosoftAD.VpcSettingsProperty, aws_cdk.core.IResolvable],
         create_alias: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
         edition: typing.Optional[builtins.str] = None,
         enable_sso: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
+        name: builtins.str,
+        password: builtins.str,
         short_name: typing.Optional[builtins.str] = None,
+        vpc_settings: typing.Union[CfnMicrosoftAD.VpcSettingsProperty, aws_cdk.core.IResolvable],
     ) -> None:
         '''Properties for defining a ``AWS::DirectoryService::MicrosoftAD``.
 
-        :param name: ``AWS::DirectoryService::MicrosoftAD.Name``.
-        :param password: ``AWS::DirectoryService::MicrosoftAD.Password``.
-        :param vpc_settings: ``AWS::DirectoryService::MicrosoftAD.VpcSettings``.
         :param create_alias: ``AWS::DirectoryService::MicrosoftAD.CreateAlias``.
         :param edition: ``AWS::DirectoryService::MicrosoftAD.Edition``.
         :param enable_sso: ``AWS::DirectoryService::MicrosoftAD.EnableSso``.
+        :param name: ``AWS::DirectoryService::MicrosoftAD.Name``.
+        :param password: ``AWS::DirectoryService::MicrosoftAD.Password``.
         :param short_name: ``AWS::DirectoryService::MicrosoftAD.ShortName``.
+        :param vpc_settings: ``AWS::DirectoryService::MicrosoftAD.VpcSettings``.
 
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html
+
+        Example::
+
+            # The code below shows an example of how to instantiate this type.
+            # The values are placeholders you should change.
+            import aws_cdk.aws_directoryservice as directoryservice
+            
+            cfn_microsoft_aDProps = directoryservice.CfnMicrosoftADProps(
+                name="name",
+                password="password",
+                vpc_settings=directoryservice.CfnMicrosoftAD.VpcSettingsProperty(
+                    subnet_ids=["subnetIds"],
+                    vpc_id="vpcId"
+                ),
+            
+                # the properties below are optional
+                create_alias=False,
+                edition="edition",
+                enable_sso=False,
+                short_name="shortName"
+            )
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "name": name,
@@ -334,38 +387,6 @@ class CfnMicrosoftADProps:
         if short_name is not None:
             self._values["short_name"] = short_name
 
-    @builtins.property
-    def name(self) -> builtins.str:
-        '''``AWS::DirectoryService::MicrosoftAD.Name``.
-
-        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-name
-        '''
-        result = self._values.get("name")
-        assert result is not None, "Required property 'name' is missing"
-        return typing.cast(builtins.str, result)
-
-    @builtins.property
-    def password(self) -> builtins.str:
-        '''``AWS::DirectoryService::MicrosoftAD.Password``.
-
-        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-password
-        '''
-        result = self._values.get("password")
-        assert result is not None, "Required property 'password' is missing"
-        return typing.cast(builtins.str, result)
-
-    @builtins.property
-    def vpc_settings(
-        self,
-    ) -> typing.Union[CfnMicrosoftAD.VpcSettingsProperty, aws_cdk.core.IResolvable]:
-        '''``AWS::DirectoryService::MicrosoftAD.VpcSettings``.
-
-        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-vpcsettings
-        '''
-        result = self._values.get("vpc_settings")
-        assert result is not None, "Required property 'vpc_settings' is missing"
-        return typing.cast(typing.Union[CfnMicrosoftAD.VpcSettingsProperty, aws_cdk.core.IResolvable], result)
-
     @builtins.property
     def create_alias(
         self,
@@ -397,6 +418,26 @@ class CfnMicrosoftADProps:
         result = self._values.get("enable_sso")
         return typing.cast(typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]], result)
 
+    @builtins.property
+    def name(self) -> builtins.str:
+        '''``AWS::DirectoryService::MicrosoftAD.Name``.
+
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-name
+        '''
+        result = self._values.get("name")
+        assert result is not None, "Required property 'name' is missing"
+        return typing.cast(builtins.str, result)
+
+    @builtins.property
+    def password(self) -> builtins.str:
+        '''``AWS::DirectoryService::MicrosoftAD.Password``.
+
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-password
+        '''
+        result = self._values.get("password")
+        assert result is not None, "Required property 'password' is missing"
+        return typing.cast(builtins.str, result)
+
     @builtins.property
     def short_name(self) -> typing.Optional[builtins.str]:
         '''``AWS::DirectoryService::MicrosoftAD.ShortName``.
@@ -406,6 +447,18 @@ class CfnMicrosoftADProps:
         result = self._values.get("short_name")
         return typing.cast(typing.Optional[builtins.str], result)
 
+    @builtins.property
+    def vpc_settings(
+        self,
+    ) -> typing.Union[CfnMicrosoftAD.VpcSettingsProperty, aws_cdk.core.IResolvable]:
+        '''``AWS::DirectoryService::MicrosoftAD.VpcSettings``.
+
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-vpcsettings
+        '''
+        result = self._values.get("vpc_settings")
+        assert result is not None, "Required property 'vpc_settings' is missing"
+        return typing.cast(typing.Union[CfnMicrosoftAD.VpcSettingsProperty, aws_cdk.core.IResolvable], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
@@ -428,6 +481,28 @@ class CfnSimpleAD(
 
     :cloudformationResource: AWS::DirectoryService::SimpleAD
     :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html
+
+    Example::
+
+        # The code below shows an example of how to instantiate this type.
+        # The values are placeholders you should change.
+        import aws_cdk.aws_directoryservice as directoryservice
+        
+        cfn_simple_aD = directoryservice.CfnSimpleAD(self, "MyCfnSimpleAD",
+            name="name",
+            password="password",
+            size="size",
+            vpc_settings=directoryservice.CfnSimpleAD.VpcSettingsProperty(
+                subnet_ids=["subnetIds"],
+                vpc_id="vpcId"
+            ),
+        
+            # the properties below are optional
+            create_alias=False,
+            description="description",
+            enable_sso=False,
+            short_name="shortName"
+        )
     '''
 
     def __init__(
@@ -435,37 +510,37 @@ class CfnSimpleAD(
         scope: aws_cdk.core.Construct,
         id: builtins.str,
         *,
-        name: builtins.str,
-        password: builtins.str,
-        size: builtins.str,
-        vpc_settings: typing.Union[aws_cdk.core.IResolvable, "CfnSimpleAD.VpcSettingsProperty"],
         create_alias: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
         description: typing.Optional[builtins.str] = None,
         enable_sso: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
+        name: builtins.str,
+        password: builtins.str,
         short_name: typing.Optional[builtins.str] = None,
+        size: builtins.str,
+        vpc_settings: typing.Union[aws_cdk.core.IResolvable, "CfnSimpleAD.VpcSettingsProperty"],
     ) -> None:
         '''Create a new ``AWS::DirectoryService::SimpleAD``.
 
         :param scope: - scope in which this resource is defined.
         :param id: - scoped id of the resource.
-        :param name: ``AWS::DirectoryService::SimpleAD.Name``.
-        :param password: ``AWS::DirectoryService::SimpleAD.Password``.
-        :param size: ``AWS::DirectoryService::SimpleAD.Size``.
-        :param vpc_settings: ``AWS::DirectoryService::SimpleAD.VpcSettings``.
         :param create_alias: ``AWS::DirectoryService::SimpleAD.CreateAlias``.
         :param description: ``AWS::DirectoryService::SimpleAD.Description``.
         :param enable_sso: ``AWS::DirectoryService::SimpleAD.EnableSso``.
+        :param name: ``AWS::DirectoryService::SimpleAD.Name``.
+        :param password: ``AWS::DirectoryService::SimpleAD.Password``.
         :param short_name: ``AWS::DirectoryService::SimpleAD.ShortName``.
+        :param size: ``AWS::DirectoryService::SimpleAD.Size``.
+        :param vpc_settings: ``AWS::DirectoryService::SimpleAD.VpcSettings``.
         '''
         props = CfnSimpleADProps(
-            name=name,
-            password=password,
-            size=size,
-            vpc_settings=vpc_settings,
             create_alias=create_alias,
             description=description,
             enable_sso=enable_sso,
+            name=name,
+            password=password,
             short_name=short_name,
+            size=size,
+            vpc_settings=vpc_settings,
         )
 
         jsii.create(self.__class__, self, [scope, id, props])
@@ -488,12 +563,6 @@ class CfnSimpleAD(
         '''
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
-    @jsii.python.classproperty # type: ignore[misc]
-    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
-        '''The CloudFormation resource type name for this resource class.'''
-        return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))
-
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="attrAlias")
     def attr_alias(self) -> builtins.str:
@@ -510,68 +579,17 @@ class CfnSimpleAD(
         '''
         return typing.cast(typing.List[builtins.str], jsii.get(self, "attrDnsIpAddresses"))
 
+    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
+        '''The CloudFormation resource type name for this resource class.'''
+        return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))
+
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="cfnProperties")
     def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))
 
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="name")
-    def name(self) -> builtins.str:
-        '''``AWS::DirectoryService::SimpleAD.Name``.
-
-        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-name
-        '''
-        return typing.cast(builtins.str, jsii.get(self, "name"))
-
-    @name.setter
-    def name(self, value: builtins.str) -> None:
-        jsii.set(self, "name", value)
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="password")
-    def password(self) -> builtins.str:
-        '''``AWS::DirectoryService::SimpleAD.Password``.
-
-        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-password
-        '''
-        return typing.cast(builtins.str, jsii.get(self, "password"))
-
-    @password.setter
-    def password(self, value: builtins.str) -> None:
-        jsii.set(self, "password", value)
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="size")
-    def size(self) -> builtins.str:
-        '''``AWS::DirectoryService::SimpleAD.Size``.
-
-        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-size
-        '''
-        return typing.cast(builtins.str, jsii.get(self, "size"))
-
-    @size.setter
-    def size(self, value: builtins.str) -> None:
-        jsii.set(self, "size", value)
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="vpcSettings")
-    def vpc_settings(
-        self,
-    ) -> typing.Union[aws_cdk.core.IResolvable, "CfnSimpleAD.VpcSettingsProperty"]:
-        '''``AWS::DirectoryService::SimpleAD.VpcSettings``.
-
-        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-vpcsettings
-        '''
-        return typing.cast(typing.Union[aws_cdk.core.IResolvable, "CfnSimpleAD.VpcSettingsProperty"], jsii.get(self, "vpcSettings"))
-
-    @vpc_settings.setter
-    def vpc_settings(
-        self,
-        value: typing.Union[aws_cdk.core.IResolvable, "CfnSimpleAD.VpcSettingsProperty"],
-    ) -> None:
-        jsii.set(self, "vpcSettings", value)
-
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="createAlias")
     def create_alias(
@@ -621,6 +639,32 @@ class CfnSimpleAD(
     ) -> None:
         jsii.set(self, "enableSso", value)
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="name")
+    def name(self) -> builtins.str:
+        '''``AWS::DirectoryService::SimpleAD.Name``.
+
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-name
+        '''
+        return typing.cast(builtins.str, jsii.get(self, "name"))
+
+    @name.setter
+    def name(self, value: builtins.str) -> None:
+        jsii.set(self, "name", value)
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="password")
+    def password(self) -> builtins.str:
+        '''``AWS::DirectoryService::SimpleAD.Password``.
+
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-password
+        '''
+        return typing.cast(builtins.str, jsii.get(self, "password"))
+
+    @password.setter
+    def password(self, value: builtins.str) -> None:
+        jsii.set(self, "password", value)
+
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="shortName")
     def short_name(self) -> typing.Optional[builtins.str]:
@@ -634,6 +678,37 @@ class CfnSimpleAD(
     def short_name(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "shortName", value)
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="size")
+    def size(self) -> builtins.str:
+        '''``AWS::DirectoryService::SimpleAD.Size``.
+
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-size
+        '''
+        return typing.cast(builtins.str, jsii.get(self, "size"))
+
+    @size.setter
+    def size(self, value: builtins.str) -> None:
+        jsii.set(self, "size", value)
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="vpcSettings")
+    def vpc_settings(
+        self,
+    ) -> typing.Union[aws_cdk.core.IResolvable, "CfnSimpleAD.VpcSettingsProperty"]:
+        '''``AWS::DirectoryService::SimpleAD.VpcSettings``.
+
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-vpcsettings
+        '''
+        return typing.cast(typing.Union[aws_cdk.core.IResolvable, "CfnSimpleAD.VpcSettingsProperty"], jsii.get(self, "vpcSettings"))
+
+    @vpc_settings.setter
+    def vpc_settings(
+        self,
+        value: typing.Union[aws_cdk.core.IResolvable, "CfnSimpleAD.VpcSettingsProperty"],
+    ) -> None:
+        jsii.set(self, "vpcSettings", value)
+
     @jsii.data_type(
         jsii_type="@aws-cdk/aws-directoryservice.CfnSimpleAD.VpcSettingsProperty",
         jsii_struct_bases=[],
@@ -651,6 +726,17 @@ class CfnSimpleAD(
             :param vpc_id: ``CfnSimpleAD.VpcSettingsProperty.VpcId``.
 
             :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-directoryservice-simplead-vpcsettings.html
+
+            Example::
+
+                # The code below shows an example of how to instantiate this type.
+                # The values are placeholders you should change.
+                import aws_cdk.aws_directoryservice as directoryservice
+                
+                vpc_settings_property = directoryservice.CfnSimpleAD.VpcSettingsProperty(
+                    subnet_ids=["subnetIds"],
+                    vpc_id="vpcId"
+                )
             '''
             self._values: typing.Dict[str, typing.Any] = {
                 "subnet_ids": subnet_ids,
@@ -693,41 +779,63 @@ class CfnSimpleAD(
     jsii_type="@aws-cdk/aws-directoryservice.CfnSimpleADProps",
     jsii_struct_bases=[],
     name_mapping={
-        "name": "name",
-        "password": "password",
-        "size": "size",
-        "vpc_settings": "vpcSettings",
         "create_alias": "createAlias",
         "description": "description",
         "enable_sso": "enableSso",
+        "name": "name",
+        "password": "password",
         "short_name": "shortName",
+        "size": "size",
+        "vpc_settings": "vpcSettings",
     },
 )
 class CfnSimpleADProps:
     def __init__(
         self,
         *,
-        name: builtins.str,
-        password: builtins.str,
-        size: builtins.str,
-        vpc_settings: typing.Union[aws_cdk.core.IResolvable, CfnSimpleAD.VpcSettingsProperty],
         create_alias: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
         description: typing.Optional[builtins.str] = None,
         enable_sso: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
+        name: builtins.str,
+        password: builtins.str,
         short_name: typing.Optional[builtins.str] = None,
+        size: builtins.str,
+        vpc_settings: typing.Union[aws_cdk.core.IResolvable, CfnSimpleAD.VpcSettingsProperty],
     ) -> None:
         '''Properties for defining a ``AWS::DirectoryService::SimpleAD``.
 
-        :param name: ``AWS::DirectoryService::SimpleAD.Name``.
-        :param password: ``AWS::DirectoryService::SimpleAD.Password``.
-        :param size: ``AWS::DirectoryService::SimpleAD.Size``.
-        :param vpc_settings: ``AWS::DirectoryService::SimpleAD.VpcSettings``.
         :param create_alias: ``AWS::DirectoryService::SimpleAD.CreateAlias``.
         :param description: ``AWS::DirectoryService::SimpleAD.Description``.
         :param enable_sso: ``AWS::DirectoryService::SimpleAD.EnableSso``.
+        :param name: ``AWS::DirectoryService::SimpleAD.Name``.
+        :param password: ``AWS::DirectoryService::SimpleAD.Password``.
         :param short_name: ``AWS::DirectoryService::SimpleAD.ShortName``.
+        :param size: ``AWS::DirectoryService::SimpleAD.Size``.
+        :param vpc_settings: ``AWS::DirectoryService::SimpleAD.VpcSettings``.
 
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html
+
+        Example::
+
+            # The code below shows an example of how to instantiate this type.
+            # The values are placeholders you should change.
+            import aws_cdk.aws_directoryservice as directoryservice
+            
+            cfn_simple_aDProps = directoryservice.CfnSimpleADProps(
+                name="name",
+                password="password",
+                size="size",
+                vpc_settings=directoryservice.CfnSimpleAD.VpcSettingsProperty(
+                    subnet_ids=["subnetIds"],
+                    vpc_id="vpcId"
+                ),
+            
+                # the properties below are optional
+                create_alias=False,
+                description="description",
+                enable_sso=False,
+                short_name="shortName"
+            )
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "name": name,
@@ -744,48 +852,6 @@ class CfnSimpleADProps:
         if short_name is not None:
             self._values["short_name"] = short_name
 
-    @builtins.property
-    def name(self) -> builtins.str:
-        '''``AWS::DirectoryService::SimpleAD.Name``.
-
-        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-name
-        '''
-        result = self._values.get("name")
-        assert result is not None, "Required property 'name' is missing"
-        return typing.cast(builtins.str, result)
-
-    @builtins.property
-    def password(self) -> builtins.str:
-        '''``AWS::DirectoryService::SimpleAD.Password``.
-
-        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-password
-        '''
-        result = self._values.get("password")
-        assert result is not None, "Required property 'password' is missing"
-        return typing.cast(builtins.str, result)
-
-    @builtins.property
-    def size(self) -> builtins.str:
-        '''``AWS::DirectoryService::SimpleAD.Size``.
-
-        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-size
-        '''
-        result = self._values.get("size")
-        assert result is not None, "Required property 'size' is missing"
-        return typing.cast(builtins.str, result)
-
-    @builtins.property
-    def vpc_settings(
-        self,
-    ) -> typing.Union[aws_cdk.core.IResolvable, CfnSimpleAD.VpcSettingsProperty]:
-        '''``AWS::DirectoryService::SimpleAD.VpcSettings``.
-
-        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-vpcsettings
-        '''
-        result = self._values.get("vpc_settings")
-        assert result is not None, "Required property 'vpc_settings' is missing"
-        return typing.cast(typing.Union[aws_cdk.core.IResolvable, CfnSimpleAD.VpcSettingsProperty], result)
-
     @builtins.property
     def create_alias(
         self,
@@ -817,6 +883,26 @@ class CfnSimpleADProps:
         result = self._values.get("enable_sso")
         return typing.cast(typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]], result)
 
+    @builtins.property
+    def name(self) -> builtins.str:
+        '''``AWS::DirectoryService::SimpleAD.Name``.
+
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-name
+        '''
+        result = self._values.get("name")
+        assert result is not None, "Required property 'name' is missing"
+        return typing.cast(builtins.str, result)
+
+    @builtins.property
+    def password(self) -> builtins.str:
+        '''``AWS::DirectoryService::SimpleAD.Password``.
+
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-password
+        '''
+        result = self._values.get("password")
+        assert result is not None, "Required property 'password' is missing"
+        return typing.cast(builtins.str, result)
+
     @builtins.property
     def short_name(self) -> typing.Optional[builtins.str]:
         '''``AWS::DirectoryService::SimpleAD.ShortName``.
@@ -826,6 +912,28 @@ class CfnSimpleADProps:
         result = self._values.get("short_name")
         return typing.cast(typing.Optional[builtins.str], result)
 
+    @builtins.property
+    def size(self) -> builtins.str:
+        '''``AWS::DirectoryService::SimpleAD.Size``.
+
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-size
+        '''
+        result = self._values.get("size")
+        assert result is not None, "Required property 'size' is missing"
+        return typing.cast(builtins.str, result)
+
+    @builtins.property
+    def vpc_settings(
+        self,
+    ) -> typing.Union[aws_cdk.core.IResolvable, CfnSimpleAD.VpcSettingsProperty]:
+        '''``AWS::DirectoryService::SimpleAD.VpcSettings``.
+
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-vpcsettings
+        '''
+        result = self._values.get("vpc_settings")
+        assert result is not None, "Required property 'vpc_settings' is missing"
+        return typing.cast(typing.Union[aws_cdk.core.IResolvable, CfnSimpleAD.VpcSettingsProperty], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
